package	jp.co.sds_corp.transfer.mixer;

import jp.co.sds_corp.transfer.IData;
import jp.co.sds_corp.transfer.IReceiveListener;
import jp.co.sds_corp.transfer.ReceiveEvent;
import jp.co.sds_corp.transfer.StatusChangeEvent;
import jp.co.sds_corp.util.config.IConfiguration;

/**
* 単純なデータMixerです。
* このクラスは、実は何もしていません。受け取ったデータを、登録されている
{@link IReceiveListener}に送信します。
changesrc要素をtrueに設定すると、データ受信イベントのソースがこのクラスに
設定されます。
<PRE>
&lt;Mixer name="SimpleMixer" class="jp.co.sds_corp.transfer.mixer.SimpleMixer"&gt;
	&lt;changesrc&gt;true&lt;/changesrc&gt;
&lt;/Mixer&gt;
</PRE>
*/
public class SimpleMixer extends AbstractMixer
{
	private static final long serialVersionUID = 1L;
	boolean	bChg = false;

	/**
	* 指定された初期情報で初期化します。
	* @param	config	初期情報
	*/
	public void init( IConfiguration config ) throws Exception {
		super.init( config );
		String	var;
		var = config.get( "changesrc", "false" );
		bChg = var.equals( "true" );
	}

	/**
	* データに何らかの変更があったときに呼び出されます。
	* @param	e		イベントソースおよびデータの変更内容を指定します。
	*/
	public void received( ReceiveEvent e ) throws Exception {
		fireReceive( e );
	}

	/**
	* データ受信イベントを通知します。
	* @param	e	 	データ受信イベント
	*/
	public synchronized void fireReceive( ReceiveEvent e )
		throws Exception
	{
		IData data = e.getData();
		if ( bChg ) {
			ReceiveEvent e2 = new ReceiveEvent( this, data );
			super.fireReceive( e2 );
		} else {
			super.fireReceive( e );
		}
	}

	/**
	* 状態に何らかの変更があったときに呼び出されます。
	* @param	e		イベントソースおよび状態の変更内容を指定します。
	*/
	public void statusChanged( StatusChangeEvent e ) throws Exception {
		fireStatusChange( e );
	}

}
